@@ -3,7 +3,7 @@ package Dist::Zilla::Plugin::Sah::Schemas;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-07-29'; # DATE
 our $DIST = 'Dist-Zilla-Plugin-Sah-Schemas'; # DIST
-our $VERSION = '0.025'; # VERSION
+our $VERSION = '0.026'; # VERSION
 
 use 5.010001;
 use strict;
@@ -141,9 +141,9 @@ sub munge_files {
                     $self->log(["Can't resolve schema (%s), skipped collecting base schemas for %s", $@, $pkg]);
                     last COLLECT_BASE_SCHEMAS;
                 }
-                my $intermediates = $res->[2]{intermediates};
-                for my $i (0..$#{$intermediates}-1) {
-                    my $mod = "Sah::Schema::$intermediates->[$i]";
+                my $resolve_path = $res->{resolve_path};
+                for my $i (1..$#{$resolve_path}) {
+                    my $mod = "Sah::Schema::$resolve_path->[$i]";
                     $self->{_used_schema_modules}{$mod}++;
                 }
             }
@@ -316,7 +316,7 @@ Dist::Zilla::Plugin::Sah::Schemas - Plugin to use when building Sah-Schemas-* di
 
 =head1 VERSION
 
-This document describes version 0.025 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2021-07-29.
+This document describes version 0.026 of Dist::Zilla::Plugin::Sah::Schemas (from Perl distribution Dist-Zilla-Plugin-Sah-Schemas), released on 2021-07-29.
 
 =head1 SYNOPSIS
 
